package com.ruoyi.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAssetBorrowRecord;
import com.ruoyi.asset.service.ITbAssetBorrowRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备借用记录Controller
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@RestController
@RequestMapping("/asset/borrow")
public class TbAssetBorrowRecordController extends BaseController
{
    @Autowired
    private ITbAssetBorrowRecordService tbAssetBorrowRecordService;

    /**
     * 查询设备借用记录列表
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetBorrowRecord tbAssetBorrowRecord)
    {
        startPage();
        List<TbAssetBorrowRecord> list = tbAssetBorrowRecordService.selectTbAssetBorrowRecordList(tbAssetBorrowRecord);
        return getDataTable(list);
    }

    /**
     * 导出设备借用记录列表
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:export')")
    @Log(title = "设备借用记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetBorrowRecord tbAssetBorrowRecord)
    {
        List<TbAssetBorrowRecord> list = tbAssetBorrowRecordService.selectTbAssetBorrowRecordList(tbAssetBorrowRecord);
        ExcelUtil<TbAssetBorrowRecord> util = new ExcelUtil<TbAssetBorrowRecord>(TbAssetBorrowRecord.class);
        util.exportExcel(response, list, "设备借用记录数据");
    }

    /**
     * 获取设备借用记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tbAssetBorrowRecordService.selectTbAssetBorrowRecordById(id));
    }

    /**
     * 新增设备借用记录
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:add')")
    @Log(title = "设备借用记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetBorrowRecord tbAssetBorrowRecord)
    {
        return toAjax(tbAssetBorrowRecordService.insertTbAssetBorrowRecord(tbAssetBorrowRecord));
    }

    /**
     * 修改设备借用记录
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:edit')")
    @Log(title = "设备借用记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetBorrowRecord tbAssetBorrowRecord)
    {
        return toAjax(tbAssetBorrowRecordService.updateTbAssetBorrowRecord(tbAssetBorrowRecord));
    }

    /**
     * 删除设备借用记录
     */
    @PreAuthorize("@ss.hasPermi('asset:borrow:remove')")
    @Log(title = "设备借用记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetBorrowRecordService.deleteTbAssetBorrowRecordByIds(ids));
    }
}
